==> openshift-model-6.7.0-sources.jar: io/fabric8/openshift/api/model/EgressNetworkPolicyRuleBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EgressNetworkPolicyRuleBuilder extends EgressNetworkPolicyRuleFluentImpl<EgressNetworkPolicyRuleBuilder> implements VisitableBuilder<EgressNetworkPolicyRule,EgressNetworkPolicyRuleBuilder>{
  public EgressNetworkPolicyRuleBuilder() {
    this(false);
  }
  public EgressNetworkPolicyRuleBuilder(Boolean validationEnabled) {
    this(new EgressNetworkPolicyRule(), validationEnabled);
  }
  public EgressNetworkPolicyRuleBuilder(EgressNetworkPolicyRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public EgressNetworkPolicyRuleBuilder(EgressNetworkPolicyRuleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EgressNetworkPolicyRule(), validationEnabled);
  }
  public EgressNetworkPolicyRuleBuilder(EgressNetworkPolicyRuleFluent<?> fluent,EgressNetworkPolicyRule instance) {
    this(fluent, instance, false);
  }
  public EgressNetworkPolicyRuleBuilder(EgressNetworkPolicyRuleFluent<?> fluent,EgressNetworkPolicyRule instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withTo(instance.getTo());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EgressNetworkPolicyRuleBuilder(EgressNetworkPolicyRule instance) {
    this(instance,false);
  }
  public EgressNetworkPolicyRuleBuilder(EgressNetworkPolicyRule instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withTo(instance.getTo());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EgressNetworkPolicyRuleFluent<?> fluent;
  Boolean validationEnabled;
  public EgressNetworkPolicyRule build() {
    EgressNetworkPolicyRule buildable = new EgressNetworkPolicyRule(fluent.getTo(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-6.8.0-sources.jar: io/fabric8/openshift/api/model/EgressNetworkPolicyRuleBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EgressNetworkPolicyRuleBuilder extends EgressNetworkPolicyRuleFluent<EgressNetworkPolicyRuleBuilder> implements VisitableBuilder<EgressNetworkPolicyRule,EgressNetworkPolicyRuleBuilder>{
  public EgressNetworkPolicyRuleBuilder() {
    this(false);
  }
  public EgressNetworkPolicyRuleBuilder(Boolean validationEnabled) {
    this(new EgressNetworkPolicyRule(), validationEnabled);
  }
  public EgressNetworkPolicyRuleBuilder(EgressNetworkPolicyRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public EgressNetworkPolicyRuleBuilder(EgressNetworkPolicyRuleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EgressNetworkPolicyRule(), validationEnabled);
  }
  public EgressNetworkPolicyRuleBuilder(EgressNetworkPolicyRuleFluent<?> fluent,EgressNetworkPolicyRule instance) {
    this(fluent, instance, false);
  }
  public EgressNetworkPolicyRuleBuilder(EgressNetworkPolicyRuleFluent<?> fluent,EgressNetworkPolicyRule instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EgressNetworkPolicyRule());

    if (instance != null) {
      fluent.withTo(instance.getTo());
      fluent.withType(instance.getType());
      fluent.withTo(instance.getTo());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EgressNetworkPolicyRuleBuilder(EgressNetworkPolicyRule instance) {
    this(instance,false);
  }
  public EgressNetworkPolicyRuleBuilder(EgressNetworkPolicyRule instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EgressNetworkPolicyRule());

    if (instance != null) {
      this.withTo(instance.getTo());
      this.withType(instance.getType());
      this.withTo(instance.getTo());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EgressNetworkPolicyRuleFluent<?> fluent;
  Boolean validationEnabled;
  public EgressNetworkPolicyRule build() {
    EgressNetworkPolicyRule buildable = new EgressNetworkPolicyRule(fluent.buildTo(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
